shellgen

package
v1.0.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 14, 2026 License: MIT Imports: 3 Imported by: 0

Documentation

Overview

Package shellgen generates shell scripts for bash and zsh bindings and widgets (such as the ctrl+g interactive widget) that integrate cheatmd natively into the user's shell environment.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func BashWidget

func BashWidget() string

BashWidget returns a bash script that binds the configured key to an interactive cheatmd widget, replacing the current command line with the selected command.

func FishWidget

func FishWidget() string

FishWidget returns a fish script that binds the configured key to an interactive cheatmd widget, replacing the current command line with the selected command.

func ZshWidget

func ZshWidget() string

ZshWidget returns a zsh script that binds the configured key to an interactive cheatmd widget, replacing the current command line with the selected command.

Types

This section is empty.

Jump to