Documentation
¶
Overview ¶
Package shellgen generates shell scripts for bash and zsh bindings and widgets (such as the ctrl+g interactive widget) that integrate cheatmd natively into the user's shell environment.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func BashWidget ¶
func BashWidget() string
BashWidget returns a bash script that binds the configured key to an interactive cheatmd widget, replacing the current command line with the selected command.
func FishWidget ¶
func FishWidget() string
FishWidget returns a fish script that binds the configured key to an interactive cheatmd widget, replacing the current command line with the selected command.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.